#
# spec file for package rasqal
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rasqal
Version:        0.9.33
Release:        bp160.1.8
%define sonum   3
Summary:        RDF Parser Toolkit for Redland
License:        LGPL-2.1+ or GPL-2.0+ or Apache-2.0+
Group:          Productivity/Other
Url:            http://librdf.org/%{name}/
Source0:        http://download.librdf.org/source/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libraptor-devel
BuildRequires:  mpfr-devel
BuildRequires:  pcre-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       lib%{name}%{sonum} = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Rasqal is a library providing full support for querying Resource
Description Framework (RDF) including parsing query syntaxes,
constructing the queries, executing them and returning result formats.
It currently handles the RDF Data Query Language (RDQL) and SPARQL
Query language.

%package -n lib%{name}%{sonum}
Summary:        RDF Parser Toolkit for Redland
Group:          System/Libraries
%requires_ge    libraptor1

%description -n lib%{name}%{sonum}
Rasqal is a library providing full support for querying Resource
Description Framework (RDF) including parsing query syntaxes,
constructing the queries, executing them and returning result formats.
It currently handles the RDF Data Query Language (RDQL) and SPARQL
Query language.

%package -n lib%{name}-devel
Summary:        Development package for the Rasqal RDF query library
Group:          Development/Languages/C and C++
Requires:       lib%{name}%{sonum} = %{version}
Requires:       libraptor-devel >= 2.0.7

%description -n lib%{name}-devel
This package contains the files needed to develop with the Rasqal RDF
query language library.

%package -n lib%{name}-devel-doc
Summary:        Documentation package for lib%{name}-devel
Group:          Development/Languages/C and C++

%description -n lib%{name}-devel-doc
This package contains the documentation and help files to aid with
developing software using the Rasqal RDF query language library.

%prep
%setup -q

%build
%configure --enable-release \
           --disable-static \
           --with-pic \
           --with-regex-library=pcre \
           --with-html-dir=%{_docdir}/lib%{name}-devel/

make %{?_smp_mflags}

%install
%make_install

rm -f %{buildroot}%{_libdir}/*.la

%post   -n lib%{name}%{sonum} -p /sbin/ldconfig

%postun -n lib%{name}%{sonum} -p /sbin/ldconfig

%files -n lib%{name}%{sonum}
%defattr(-,root,root,-)
%doc AUTHORS COPYING COPYING.LIB ChangeLog 
%doc LICENSE-2.0.txt LICENSE.html LICENSE.txt 
%doc NEWS NEWS.html NOTICE README README.html RELEASE.html
%{_libdir}/lib%{name}.so.%{sonum}*
%{_mandir}/man1/%{name}-config.1%{ext_man}

%files -n lib%{name}-devel
%defattr(-,root,root,-)
%{_bindir}/%{name}-config
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/lib%{name}.3%{ext_man}

%files -n lib%{name}-devel-doc
%defattr(-,root,root,-)
%{_docdir}/lib%{name}-devel/

%files
%defattr(-,root,root,-)
%{_bindir}/roqet
%{_mandir}/man1/roqet.1%{ext_man}

%changelog
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 0.9.33
  * Added support for reading and writing boolean result formats.
  * Fixed several query engine operator evaluations (AVG, STRBEFORE,
  * STRAFTER, CONCAT)
  * Updated query results class constructor and methods, deprecating older.
  * Portability fixes for ICC, clang and GCC 5.
  * New internal test runner utility
  * Variable bindings query results can be formatted in mKR CSV format.
  * Multiple other fixes and improvements including fixing reported issues:
    0000546, 0000568, 0000583 and 0000588.
- Remove redundant %%clean section
* Sat Feb  2 2013 hrvoje.senjan@gmail.com
- Update to version 0.9.30:
  + Removed RDQL support
  + Improved floating equality, comparison and promotion rules
  + Other fixes and improvements
* Fri Feb  1 2013 coolo@suse.com
- update license again
* Mon May 21 2012 zaitor@opensuse.org
- Update to version 0.9.29:
  + Supports all of SPARQL 1.0 by passing 100%% of the approved
    tests.
  + Added support for XSD date.
  + Made XSD dateTime and XSD date equality and comparison work
  + Make limit and offset check work properly in a subquery
  + Correctly handle errors during aggregation expressions
    evaluation
  + Fix blank node generation when made in a CONSTRUCT to match
    SPARQL
  + Added SPARQL 1.1 draft UUID() and STRUUID() support
  + Requires Raptor 2.0.7+
  + RDQL support will be removed in the next release (0.9.30)
  + Made other fixes and improvements including fixing reported
    issues: 0000493, 0000494 0000504 (http://bugs.librdf.org/)
* Mon Jan 23 2012 dmueller@suse.de
- add baselibs.conf
* Wed Jan  4 2012 crrodriguez@opensuse.org
- remove libmhash buildrequires, which development was
  abandoned on 2007-08-18 and therefore should not be used.
  the library will fallback to internal hashing routines.
- remove obsolete configure options/cflags
* Wed Dec 21 2011 tittiatcoke@gmail.com
- Remove the specific -32bit compilation for 64bit systems. This
  as that rasqal depends on mhash for which there is no -32bit
  package
* Wed Dec 21 2011 tittiatcoke@gmail.com
- Update to 0.9.28
  * Added full support for SPARQL 1.1 draft STRBEFORE, STRAFTER
    and REPLACE.
  * Add internal Mersenne Twister PRNG or choose others via
    configure
  * Language name 'sparql' is now SPARQL 1.1
  * The query result formats now all use the W3C Format URIs as
    their primary URI
  * Improved configure check for for ceil(), floor() and round()
    to prevent GCC optimizing the test away and getting the wrong
    answer
  * Bugfixes
* Sat Oct  8 2011 toddrme2178@gmail.com
- Split documentation package (fix for RPMLINT warning)
- Added mhash buildrequires
- Cleaned up spec file formatting
* Mon Sep 19 2011 tittiatcoke@gmail.com
- Update to 0.9.27
  * sub-SELECTs can now be executed
  * OPTIONAL and UNION fully execute correctly
  * Grouping over sub-graph patterns fully executes correctly
  * CONSTRUCT WHERE abbreviation is supported and executes
  * CONSTRUCT works when working over a query with optionals
  * Updated the CSV and TSV outputs to match the editor's draft
    SPARQL 1.1 Query Results CSV and TSV Formats
  * Fixed issues: [1]#0000127, [2]#0000423, [3]#0000434, [4]#0000454
    and [5]#0000459.
* Sun May 22 2011 asterios.dramis@gmail.com
- Update to 0.9.21:
  * Updated to handle aggregate expression execution as defined by the
    SPARQL 1.1 Query W3C working draft of 14 October 2010
  * Executes grouping of results: GROUP BY
  * Executes aggregate expressions: AVG, COUNT, GROUP_CONCAT, MAX, MIN,
    SAMPLE, SUM
  * Executes filtering of aggregate expressions: HAVING
  * Parses new syntax: BINDINGS, isNUMERIC(), MINUS, sub SELECT and
    SERVICE.
  * The syntax format for parsing data graphs at URIs can be explictly
    declared.
  * The roqet utility can execute queries over SPARQL HTTP Protocol and
    operate over data from stdin.
  * Added several new APIs
  * Fixed Issue: #0000388
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to LGPLv2.1+ or GPLv2+ or ASLv2.0+.
  * Changed rasqal Group to Productivity/Other.
  * Added mpfr-devel in BuildRequires:.
  * Removed gtk-doc from BuildRequires: (not needed to build html docs).
  * Removed autoreconf from %%build section and simplified configure.
  * Install html docs in %%{_docdir}/librasqal-devel/.
  * Minor other updates.
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
- removed package name from summary (fix for RPMLINT warning)
* Tue Oct 19 2010 dmueller@suse.de
- update to 0.9.20:
  * Updated to handle more of the new syntax defined by the SPARQL 1.1
    Query and SPARQL 1.1 Update W3C working drafts of 1 June 2010
    Added execution support for new SPARQL 1.1 query built-in expressions
    IF, URI, STRLANG, STRDT, BNODE, IN and NOT IN.
    Added an 'html' query result table format from patch by Nicholas J
    Humfrey
    Added API support for group by HAVING expressions
    Added XSD Date comparison support
    Support building with Raptor V2 API if configured with --with-raptor2.
    Many other bug fixes and improvements were made.
    Fixed Issues: #0000352, #0000353, #0000354, #0000360, #0000374,
    [#0000377] and #0000378
    See the Rasqal 0.9.20 Release Notes for the full details of the
    changes.
* Sun Apr 11 2010 beineri@opensuse.org
- update to 0.9.19:
  * Add initial draft parsing and API (NOT execution) support for
    SPARQL 1.1 Update W3C Working Draft of 2010-01-26.
  * Add public APIs (row, results, result formatter, variables table)
    so that query results can be built, read and written without query.
  * Add API resilience checks for invalid NULL pointer arguments.
  * Many other bug fixes and improvements were made.
* Sat Jan  2 2010 dmueller@suse.de
- update to 0.9.17:
  Added a new query engine that implements the SPARQL algebra better
  All constructors now take a rasqal_world argument
  Added LAQRS syntax support for SUM, AVG, MIN, MAX, COALESCE()
  experimental syntax
  Added query result formatters for CSV, TSV and ASCII tables
  Prefer pkg-config for configuring
  Many resilience and resource failure fixes by Lauri Aalto
  Many other bug fixes and improvements were made
  Fixed Issues: Issue#0000077, Issue#0000128, Issue#0000168,
  Issue#0000258, Issue#0000261, Issue#0000271, Issue#0000279 and
  Issue#0000305
* Thu Jul 24 2008 dmueller@suse.de
- update to version 0.9.16:
  * Added a rasqal_world object used for all constructor functions
  * Removed deprecated functions and macros
  * Fixed some memory leaks and made some low-memory resiliance fixes
  * Query result sets can be read/written from sparql XML results format
  * Improved error syntax error reporting
* Sat Jan  5 2008 dmueller@suse.de
- update buildrequires
* Sat Dec 15 2007 stbinner@suse.de
- Update to version 0.9.15
  * Many updates for supporting W3C SPARQL Proposed Recommendation.
    Passes over 92%% of the DAWG SPARQL Test Suite.
  * Many query engine improvements.
  * Substantial improvements to datatypes support and evaluation.
  * Many improvements and fixes for use in low-memory situations
  * Several new APIs were added including a new XSD decimal class
* Sun Aug 26 2007 crrodriguez@suse.de
- build needs -fno-strict-aliasing.
- PCRE is the recommended regex library and the default but
  package neither required pcre-devel nor the autodetection worked.
- add missing calls to ldconfig.
- remove unneeded static libraries and libtool archives.
* Fri May  4 2007 dmueller@suse.de
- Fix package requires
* Thu May  3 2007 wstephenson@suse.de
- name -devel subpackage correctly
* Wed May  2 2007 wstephenson@suse.de
- Update to version 0.9.14
  * Added syntax and API support (but no query engine support)
    for experimental extensions to SPARQL called LAQRS:
    LAQRS Adds to Querying RDF in SPARQL.
  * Fixed issues: Issue#0000152, Issue#0000156, Issue#0000160,
    Issue#0000167, Issue#0000182, from the Redland Issue Tracker.
- Version 0.9.13
  * Added a new rasqal_query_results_formatter class.
  * Many internal query engine changes, mostly to separate query
    and query_results internals so that eventually the run-time
    execution context is entirely separated from the static query structure.
  * Added query features system with one initial feature RASQAL_FEATURE_NO_NET.
* Thu Jul 13 2006 mrueckert@suse.de
- spec file cleanup
* Mon Jun 26 2006 dmacvicar@suse.de
- initial package of 0.9.12
